@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -27,6 +27,7 @@ from .literals import (
     DeliverabilityTestStatusType,
     DimensionValueSourceType,
     DkimSigningAttributesOriginType,
+    DkimSigningKeyLengthType,
     DkimStatusType,
     EventTypeType,
     IdentityTypeType,
@@ -42,7 +43,7 @@ from .literals import (
     WarmupStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -293,7 +294,7 @@ _RequiredBulkEmailEntryTypeDef = TypedDict(
 _OptionalBulkEmailEntryTypeDef = TypedDict(
     "_OptionalBulkEmailEntryTypeDef",
     {
-        "ReplacementTags": List["MessageTagTypeDef"],
+        "ReplacementTags": Sequence["MessageTagTypeDef"],
         "ReplacementEmailContent": "ReplacementEmailContentTypeDef",
     },
     total=False,
@@ -307,7 +308,7 @@ class BulkEmailEntryTypeDef(_RequiredBulkEmailEntryTypeDef, _OptionalBulkEmailEn
 CloudWatchDestinationTypeDef = TypedDict(
     "CloudWatchDestinationTypeDef",
     {
-        "DimensionConfigurations": List["CloudWatchDimensionConfigurationTypeDef"],
+        "DimensionConfigurations": Sequence["CloudWatchDimensionConfigurationTypeDef"],
     },
 )
 
@@ -390,7 +391,7 @@ _OptionalCreateConfigurationSetRequestRequestTypeDef = TypedDict(
         "DeliveryOptions": "DeliveryOptionsTypeDef",
         "ReputationOptions": "ReputationOptionsTypeDef",
         "SendingOptions": "SendingOptionsTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "SuppressionOptions": "SuppressionOptionsTypeDef",
     },
     total=False,
@@ -413,9 +414,9 @@ _RequiredCreateContactListRequestRequestTypeDef = TypedDict(
 _OptionalCreateContactListRequestRequestTypeDef = TypedDict(
     "_OptionalCreateContactListRequestRequestTypeDef",
     {
-        "Topics": List["TopicTypeDef"],
+        "Topics": Sequence["TopicTypeDef"],
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -437,7 +438,7 @@ _RequiredCreateContactRequestRequestTypeDef = TypedDict(
 _OptionalCreateContactRequestRequestTypeDef = TypedDict(
     "_OptionalCreateContactRequestRequestTypeDef",
     {
-        "TopicPreferences": List["TopicPreferenceTypeDef"],
+        "TopicPreferences": Sequence["TopicPreferenceTypeDef"],
         "UnsubscribeAll": bool,
         "AttributesData": str,
     },
@@ -472,7 +473,7 @@ _RequiredCreateDedicatedIpPoolRequestRequestTypeDef = TypedDict(
 _OptionalCreateDedicatedIpPoolRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDedicatedIpPoolRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -496,7 +497,7 @@ _OptionalCreateDeliverabilityTestReportRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDeliverabilityTestReportRequestRequestTypeDef",
     {
         "ReportName": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -536,7 +537,7 @@ _RequiredCreateEmailIdentityRequestRequestTypeDef = TypedDict(
 _OptionalCreateEmailIdentityRequestRequestTypeDef = TypedDict(
     "_OptionalCreateEmailIdentityRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "DkimSigningAttributes": "DkimSigningAttributesTypeDef",
         "ConfigurationSetName": str,
     },
@@ -726,9 +727,9 @@ DeliveryOptionsTypeDef = TypedDict(
 DestinationTypeDef = TypedDict(
     "DestinationTypeDef",
     {
-        "ToAddresses": List[str],
-        "CcAddresses": List[str],
-        "BccAddresses": List[str],
+        "ToAddresses": Sequence[str],
+        "CcAddresses": Sequence[str],
+        "BccAddresses": Sequence[str],
     },
     total=False,
 )
@@ -740,6 +741,9 @@ DkimAttributesTypeDef = TypedDict(
         "Status": DkimStatusType,
         "Tokens": List[str],
         "SigningAttributesOrigin": DkimSigningAttributesOriginType,
+        "NextSigningKeyLength": DkimSigningKeyLengthType,
+        "CurrentSigningKeyLength": DkimSigningKeyLengthType,
+        "LastKeyGenerationTimestamp": datetime,
     },
     total=False,
 )
@@ -749,7 +753,9 @@ DkimSigningAttributesTypeDef = TypedDict(
     {
         "DomainSigningSelector": str,
         "DomainSigningPrivateKey": str,
+        "NextSigningKeyLength": DkimSigningKeyLengthType,
     },
+    total=False,
 )
 
 DomainDeliverabilityCampaignTypeDef = TypedDict(
@@ -828,7 +834,7 @@ EventDestinationDefinitionTypeDef = TypedDict(
     "EventDestinationDefinitionTypeDef",
     {
         "Enabled": bool,
-        "MatchingEventTypes": List[EventTypeType],
+        "MatchingEventTypes": Sequence[EventTypeType],
         "KinesisFirehoseDestination": "KinesisFirehoseDestinationTypeDef",
         "CloudWatchDestination": "CloudWatchDestinationTypeDef",
         "SnsDestination": "SnsDestinationTypeDef",
@@ -887,7 +893,7 @@ GetAccountResponseTypeDef = TypedDict(
 GetBlacklistReportsRequestRequestTypeDef = TypedDict(
     "GetBlacklistReportsRequestRequestTypeDef",
     {
-        "BlacklistItemNames": List[str],
+        "BlacklistItemNames": Sequence[str],
     },
 )
 
@@ -1495,7 +1501,7 @@ class ListManagementOptionsTypeDef(
 ListSuppressedDestinationsRequestRequestTypeDef = TypedDict(
     "ListSuppressedDestinationsRequestRequestTypeDef",
     {
-        "Reasons": List[SuppressionListReasonType],
+        "Reasons": Sequence[SuppressionListReasonType],
         "StartDate": Union[datetime, str],
         "EndDate": Union[datetime, str],
         "NextToken": str,
@@ -1603,7 +1609,7 @@ _OptionalPutAccountDetailsRequestRequestTypeDef = TypedDict(
     "_OptionalPutAccountDetailsRequestRequestTypeDef",
     {
         "ContactLanguage": ContactLanguageType,
-        "AdditionalContactEmailAddresses": List[str],
+        "AdditionalContactEmailAddresses": Sequence[str],
         "ProductionAccessEnabled": bool,
     },
     total=False,
@@ -1627,7 +1633,7 @@ PutAccountSendingAttributesRequestRequestTypeDef = TypedDict(
 PutAccountSuppressionAttributesRequestRequestTypeDef = TypedDict(
     "PutAccountSuppressionAttributesRequestRequestTypeDef",
     {
-        "SuppressedReasons": List[SuppressionListReasonType],
+        "SuppressedReasons": Sequence[SuppressionListReasonType],
     },
     total=False,
 )
@@ -1708,7 +1714,7 @@ _RequiredPutConfigurationSetSuppressionOptionsRequestRequestTypeDef = TypedDict(
 _OptionalPutConfigurationSetSuppressionOptionsRequestRequestTypeDef = TypedDict(
     "_OptionalPutConfigurationSetSuppressionOptionsRequestRequestTypeDef",
     {
-        "SuppressedReasons": List[SuppressionListReasonType],
+        "SuppressedReasons": Sequence[SuppressionListReasonType],
     },
     total=False,
 )
@@ -1768,7 +1774,7 @@ _RequiredPutDeliverabilityDashboardOptionRequestRequestTypeDef = TypedDict(
 _OptionalPutDeliverabilityDashboardOptionRequestRequestTypeDef = TypedDict(
     "_OptionalPutDeliverabilityDashboardOptionRequestRequestTypeDef",
     {
-        "SubscribedDomains": List["DomainDeliverabilityTrackingOptionTypeDef"],
+        "SubscribedDomains": Sequence["DomainDeliverabilityTrackingOptionTypeDef"],
     },
     total=False,
 )
@@ -1948,7 +1954,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
@@ -1966,7 +1972,7 @@ _RequiredSendBulkEmailRequestRequestTypeDef = TypedDict(
     "_RequiredSendBulkEmailRequestRequestTypeDef",
     {
         "DefaultContent": "BulkEmailContentTypeDef",
-        "BulkEmailEntries": List["BulkEmailEntryTypeDef"],
+        "BulkEmailEntries": Sequence["BulkEmailEntryTypeDef"],
     },
 )
 _OptionalSendBulkEmailRequestRequestTypeDef = TypedDict(
@@ -1974,10 +1980,10 @@ _OptionalSendBulkEmailRequestRequestTypeDef = TypedDict(
     {
         "FromEmailAddress": str,
         "FromEmailAddressIdentityArn": str,
-        "ReplyToAddresses": List[str],
+        "ReplyToAddresses": Sequence[str],
         "FeedbackForwardingEmailAddress": str,
         "FeedbackForwardingEmailAddressIdentityArn": str,
-        "DefaultEmailTags": List["MessageTagTypeDef"],
+        "DefaultEmailTags": Sequence["MessageTagTypeDef"],
         "ConfigurationSetName": str,
     },
     total=False,
@@ -2041,10 +2047,10 @@ _OptionalSendEmailRequestRequestTypeDef = TypedDict(
         "FromEmailAddress": str,
         "FromEmailAddressIdentityArn": str,
         "Destination": "DestinationTypeDef",
-        "ReplyToAddresses": List[str],
+        "ReplyToAddresses": Sequence[str],
         "FeedbackForwardingEmailAddress": str,
         "FeedbackForwardingEmailAddressIdentityArn": str,
-        "EmailTags": List["MessageTagTypeDef"],
+        "EmailTags": Sequence["MessageTagTypeDef"],
         "ConfigurationSetName": str,
         "ListManagementOptions": "ListManagementOptionsTypeDef",
     },
@@ -2150,7 +2156,7 @@ SuppressionListDestinationTypeDef = TypedDict(
 SuppressionOptionsTypeDef = TypedDict(
     "SuppressionOptionsTypeDef",
     {
-        "SuppressedReasons": List[SuppressionListReasonType],
+        "SuppressedReasons": Sequence[SuppressionListReasonType],
     },
     total=False,
 )
@@ -2159,7 +2165,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -2246,7 +2252,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -2268,7 +2274,7 @@ _RequiredUpdateContactListRequestRequestTypeDef = TypedDict(
 _OptionalUpdateContactListRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateContactListRequestRequestTypeDef",
     {
-        "Topics": List["TopicTypeDef"],
+        "Topics": Sequence["TopicTypeDef"],
         "Description": str,
     },
     total=False,
@@ -2291,7 +2297,7 @@ _RequiredUpdateContactRequestRequestTypeDef = TypedDict(
 _OptionalUpdateContactRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateContactRequestRequestTypeDef",
     {
-        "TopicPreferences": List["TopicPreferenceTypeDef"],
+        "TopicPreferences": Sequence["TopicPreferenceTypeDef"],
         "UnsubscribeAll": bool,
         "AttributesData": str,
     },
